#
# spec file for package translate-shell
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           translate-shell
Version:        0.9.7.1
Release:        1.1
Summary:        Command line translator using various online services as backends
License:        Unlicense
Group:          Productivity/Networking/Web/Frontends
URL:            https://www.soimort.org/translate-shell
Source:         https://github.com/soimort/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  emacs-nox
BuildRequires:  gawk >= 4.0
BuildRequires:  rlwrap
Requires:       bash
Requires:       gawk >= 4.0
Recommends:     curl
Recommends:     fribidi
Recommends:     less
Recommends:     rlwrap
Suggests:       emacs-nox
Suggests:       mpv
BuildArch:      noarch

%description
Translate Shell is a command-line translator powered by
Google Translate, Bing Translator, Yandex.Translate and DeepL
traslator. It gives access to online translation services
from a terminal.

%prep
%setup -q

%build
%make_build

%install
%make_install PREFIX=%{_prefix}
chmod -x %{buildroot}%{_mandir}/man1/trans.1
sed -i 's|%{_bindir}/env bash|/bin/bash|' %{buildroot}%{_bindir}/trans

%files
%license LICENSE
%doc CONTRIBUTING.md README.md WAIVER
%{_bindir}/trans
%{_mandir}/man1/trans.1%{?ext_man}

%changelog
* Sun Mar 12 2023 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.9.7.1:
  * Bing Translator: fixed engine support.
  * Apertium Translator: (partly) fixed engine support.
  * REPL: supported setting sl and tl by :set.
* Mon Oct 10 2022 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.9.7:
  * Translate-Shell now recognizes 159 languages in total (including
    all the languages currently supported by Google Translate, Bing Translator,
    and Yandex.Translate)
  * Google Translate: fixed a regression bug (bac44df)
  * Bing Translator: fixed engine support (4a3a900)
  * Show HTTP error codes (892b543)
  * The default engine is now changed to auto (which uses google by
    default, but automatically falls back on bing if the specified language
    is not supported by Google Translate)
  * The options -l / -lang for specifying the interface language are
    deprecated in favor of -hl / -host; the environment variable HOME_LANG
    is deprecated in favor of HOST_LANG
  * 4 new options: -list-languages, -list-languages-english, -list-codes,
  - list-all to list all languages and codes
  * The options -L / -linguist (-list is deprecated) now show more
    linguistic details about languages
* Wed Aug 26 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.9.6.12
  * Bing Microsoft Translator: fixed (#340)
  * Added a Docker image (#336)
  * Fixed other minor issues (#345, #339)
* Wed Sep 18 2019 Yifan Jiang <yfjiang@suse.com>
- Update to version 0.9.6.11
  * Google Translate: enforced UTF-8 URL-encoding for non-ASCII
    characters, fixed garbled result
  * Bing Microsoft Translator: updated to API v3, fixed support
    (excl. TTS)
  * GNU awk 5.0.0 compatibility
- includes version 0.9.6.10
  * GNU awk 5.0.0 compatibility
  * Show gender-specific translations (Google Translate only)
  * Support multiple source languages Support the use of language
    aliases for TTS
  * Fix for virtual emulators that have own BiDi support, e.g.,
    konsole
  * New option: -bidi (enforce bidirectional conversion)
  * New options: -4, -6 (choose manually IPv4 or IPv6 connection)
  * New option: -no-browser (do not open the web browser)
  * New option: -join-sentence (treat all arguments as one single
    sentence)
  * Multiple fixes
- includes version 0.9.6.9
  * Removed DeepL engine support
  * Close command pipelines after printing to pager
  * Set minimum screen width
* Tue Aug 21 2018 idonmez@suse.com
- Update to version 0.9.6.8
  * Fixed engine support: DeepL, Bing TTS
  * New languages (Yandex only): Emoji
  * Close command pipelines everywhere
* Mon Apr 30 2018 jengelh@inai.de
- Update description.
* Sun Apr 29 2018 avindra@opensuse.org
- Update to version 0.9.6.7:
  * Bing translator
  * 3 new languages for Yandex (Hill Mari, Eastern Mari, Papiamento)
  * Show transliteration for Bing and Yandex
  * print only language code when specifying -brief -identity
- includes 0.9.6.6:
  * DeepL translator
  * 3 new options (-dump, -download-audio/-download-audio-as, -no-warn)
- includes 0.9.6.5:
  * HTTP proxy support
  * display all alternative translations
  * rlwrap invocation regression fixed
- includes 0.9.6.4:
  * fix locale detection
  * fix extra spaces between sentences when using google
- cleanup with spec-cleaner
- update summary and description to reflect new services
- remove check for now (curl test failing)
- fix E: env-script-interpreter
* Tue May  9 2017 sor.alexei@meowr.ru
- Update to version 0.9.6.3:
  * No changelog available.
* Sat May 28 2016 sor.alexei@meowr.ru
- Update to version 0.9.4:
  * No changelog available.
* Mon Mar 14 2016 idonmez@suse.com
- Update to 0.9.3.2
  * No changelog upstream
- Run tests with a UTF-8 locale.
* Fri Mar  4 2016 sor.alexei@meowr.ru
- Update to 0.9.3.1.
* Thu Feb 11 2016 sor.alexei@meowr.ru
- Update to 0.9.3.
* Tue Dec 29 2015 sor.alexei@meowr.ru
- Update to 0.9.2.1.
* Mon Nov 23 2015 sor.alexei@meowr.ru
- Update to 0.9.1:
  * Fix play() with placeholder parameter "&tk".
  * Add -speak and -identify options.
  * Allow names and endonyms as language aliases.
  * -i will nowt fail if input file was not found.
* Sat Oct 10 2015 sor.alexei@meowr.ru
- Update to 0.9.0.9:
  * Add a placeholder for the access token in parameters.
* Sun Sep 13 2015 sor.alexei@meowr.ru
- Update to 0.9.0.8:
  * Create man directory during make install.
  * Fix play().
  * Set default user agent.
- Remove translate-shell-add-useragent.patch: fixed upstream.
* Thu Jul 30 2015 sor.alexei@meowr.ru
- Initial package.
